#-------------------------------------------------------------------------------
# @(#) xml-3gpp/tech_pack_support/Ericsson_IMS/EngineConfig.pm xml-3gpp_r3.2.1.2:cset.002211:2:2@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# My Vendor Interface
#
# Copyright (C) 2005 Vallent Software Systems UK. All rights reserved.

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();

# DDM configuration
use DDM_MANIP_Config;
use AudLog;

#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = (
    {
        #-----------------------------------------------------------------------
        # XML_3GPP Rule to handle OamProvisioningCounter and PlatformMeasures 
        # 
        #-----------------------------------------------------------------------
        RULE_TYPE                        => 'XML_3GPP',
        RULE_DESC                        => '3GPP XML Interface',
#        INPUT_FILE_DESCRIPTION           => ['^.+_reporterLogs_.+$'],
        INPUT_FILE_DESCRIPTION           => ['^.+hss.+$',
                                             '^.+cscf.+$'],
        INPUT_DIR_DEPTH                  => 0,
        FILENAME_HEADER_FIELDS           => {
                                              Type       => '^.*(\w{1})\d{8}.+$',
                                              StartDate  => '^.*\w{1}(\d{8}).+$',
                                              StartTime  => '^.*\w{1}\d{8}\.(\d{4}).+$',
                                              Filename   => '^(.*)$',
                                              },
        XML_PIF_HEADER_ELEMENT_NAMES     => ['ffvv-_f.v','sn','st','vn','cbt','nedn','ts'],
        XML_UNIQUE_PIF_BLOCK_HEADER_ELEMENT_NAMES    => ['mts','gp'],
        XML_3GPP_FILENAME_VALIDATION     =>    {
                                                 Type      => '^.*(A|B|C|D)\d{8}.+$',
                                                 StartDate => '^.*\w{1}(\d{8}).+$',
                                                 StartTime => '^.*\w{1}\d{8}\.(\d{4}).+$',
                                                 EndTime   => '^.*\w{1}\d{8}\.\d{4}-(\d{4}).*',
                                              },
        XML_HEADER_INFO_FOR_PIF_FILENAME     => ['Type','mts','sn_g3ManagedElement'],
        XML_UNIQUE_PIF_BLOCK_ELEMENT_NAME    => 'mi',
        XML_MEASUREMENT_TYPE_ELEMENT_SEQ     => 'mt',
        XML_MEASUREMENT_VALUE_ELEMENT_NAME   => 'mv',
        XML_MEASUREMENT_RESULTS_ELEMENT_SEQ  => 'r',
        XML_OUTPUT_BLOCK_ELEMENT_NAME        => 'moid',
        XML_OUTPUT_BLOCK_DESCRIPTION         => '^(\w[\-\w]*)\s*=?\s*\"?[\/\-\w]*\"?\s*\,?\s*([\-\w]*)\s*=?\s*\"?[\/\-\w]*\"?\s*\,?\s*([\-\w]*)\s*=?\s*[\/\-\w]*',
        XML_OBJECT_INSTANCE_ID_ELEMENT_NAME  => 'moid',
        XML_ENABLE_PIF_PER_MOID              => '0',
        XML_SUSPECT_FLAG_ELEMENT_NAME        => 'sf',
        XML_ALTERNATIVE_COUNTER_NULL_VALUE   => '-9999',
        XML_MAX_COUNTER_NAME_SIZE            => '300',
        XML_LINE_COUNT_TO_TOP_TRIM           => 0,
        XML_ALTERNATIVE_OUTPUT_BLOCK_NAMES   => {
                                                 'HSS_.*' => 'HSS',
                                               },
        XML_ENABLE_PIF_COUNTER_IN_FILENAME   => 'true',
        XML_DDM_MANIP_RULES  => ddm_manip_config(),
        # This entry enables extra Perl code in the engine to do various manipulation
        # to header and data records. This is the last process within the engine
        # before the data is being output to the PIF files. Change CSV_DATA to
        # the actual OUTPUT_BLOCK_NAME configured above.
        #
        HEADER_DATA_RECORD_PROCESSING => sub {
            my ($blkname_ref, $h_ref, $d_ref) = @_;

            unless ( exists($h_ref->{GMT_difference}) ) {
                ($h_ref->{GMT_difference}) = $h_ref->{mts} =~ /^\d{14}\.\d{0,4}([+-]?\d{0,4})$/;
            }
	    my $name;
	    for my $d_key (keys %$d_ref) {
			$name = $d_key;
			if ($d_ref->{$name} =~ /e\+\d+$/) {
				$d_ref->{$name} = sprintf("%d",$d_ref->{$name});
			}
                        # Bug 57138 
                        # Add "0" when data is NULL
                        if (! $d_ref->{$name}) {
                                $d_ref->{$name} = 0 ;
                        }
	    }

            return 0;
        },
    },

    {
        #-----------------------------------------------------------------------
        # XML_3GPP Rule to handle Server Application, Server DS, BW_MedSerMCP Media, 
        # Server DNS and IPMM_Ipwrk_DnsUpdate DNS  
        #-----------------------------------------------------------------------
        RULE_TYPE                        => 'XML_3GPP',
        RULE_DESC                        => '3GPP XML Interface',
        INPUT_FILE_DESCRIPTION           => ['^A\d{8}\.\d{4}-(\d{4}).+\.xml$'],
        INPUT_DIR_DEPTH                  => 0,
        FILENAME_HEADER_FIELDS           => {
                                              Type       => '^(\w{1})\d{8}.+$',
                                              StartDate  => '^\w{1}(\d{8}).+$',
                                              StartTime  => '^\w{1}\d{8}\.(\d{4}).+$',
                                              Filename   => '^(.*)$',
                                              },
        XML_PIF_HEADER_ELEMENT_NAMES     => ['ffvv-_f.v','sn','st','vn','cbt','nedn','ts'],
        XML_UNIQUE_PIF_BLOCK_HEADER_ELEMENT_NAMES    => ['gp', 'mts'],
        XML_3GPP_FILENAME_VALIDATION     =>    {
                                                 Type      => '^(\w{1})\d{8}.*$',
                                                 StartDate => '^\w{1}(\d{8}).*$',
                                                 StartTime => '^\w{1}\d{8}\.(\d{4}).*$',
                                                 EndTime   => '^\w{1}\d{8}\.\d{4}-(\d{4}).*',
                                              },
        XML_HEADER_INFO_FOR_PIF_FILENAME     => ['Type','mts','sn_ManagedElement'],
        XML_UNIQUE_PIF_BLOCK_ELEMENT_NAME    => 'mi',
        XML_MEASUREMENT_TYPE_ELEMENT_SEQ     => 'mt',
        XML_MEASUREMENT_VALUE_ELEMENT_NAME   => 'mv',
        XML_MEASUREMENT_RESULTS_ELEMENT_SEQ  => 'r',
        XML_OUTPUT_BLOCK_ELEMENT_NAME        => 'moid',
        XML_OUTPUT_BLOCK_DESCRIPTION         => '^(\w[\-\w]*)=\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*([\-\w]*)=*\"*[\-\w]*\"*\,*',
        XML_OBJECT_INSTANCE_ID_ELEMENT_NAME  => 'moid',
        XML_ENABLE_PIF_PER_MOID              => 0,
        XML_SUSPECT_FLAG_ELEMENT_NAME        => 'sf',
        XML_DATA_FOR_PIF_RECORD              => [ qw( mts SubNetwork ) ],
        XML_ALTERNATIVE_COUNTER_NULL_VALUE   => '-9999',
        XML_MAX_COUNTER_NAME_SIZE            => 300,
        XML_LINE_COUNT_TO_TOP_TRIM           => 0,
        XML_ALTERNATIVE_OUTPUT_BLOCK_NAMES   => {
                                                 "iso_org_dod_internet_private_enterprises_ericsson_ericssonMgcfRoot_ericssonMgcfModules_mgcfSipModule_mgcfSipObjects_sipStatisticsGroup" => "ERICSSON_MGCF_SIP_MIB",
                                               },
        XML_ENABLE_PIF_COUNTER_IN_FILENAME   => 'true',
        XML_DDM_MANIP_RULES  => ddm_manip_config(),
        # This entry enables extra Perl code in the engine to do various manipulation
        # to header and data records. This is the last process within the engine
        # before the data is being output to the PIF files. Change CSV_DATA to
        # the actual OUTPUT_BLOCK_NAME configured above.
        #
        HEADER_DATA_RECORD_PROCESSING => sub {
            my ($blkname_ref, $h_ref, $d_ref) = @_;

            unless ( exists($h_ref->{GMT_difference}) ) {
                ($h_ref->{GMT_difference}) = $h_ref->{mts} =~ /^\w{1}\d{8}\.\d{4}([+-]?\d{0,4}).*$/;
            }

            for ($h_ref->{Filename}) {
                /^.*csas\d+/ && do {
		    if ( ( exists($d_ref->{bwInstantConferencingGroupIndex}) ) && $d_ref->{bwInstantConferencingGroupID} ) {
                    	$$blkname_ref = 'Server_app_confgroup';
		    } else {
                    	$$blkname_ref = 'Server_app';
		    }
                };
                /^.*csds\d+/ && do {
                    $$blkname_ref = 'Server_ds';
                };
                /^.*csms\d+/ && do {
                    $$blkname_ref = 'BW_MedSerMCP_media';
                };
                /^.*edns\d+/ && do {
#                    $$blkname_ref = 'Server_dns';
                    $$blkname_ref = 'IPMM_Ipwrk_DnsUnsucc';
                };
                /^.*idns\d+/ && do {
                    $$blkname_ref = 'IPMM_Ipwrk_DnsUpdate_dns';
                };
                /^.*mgcsg\d+/ && do {
                    $$blkname_ref = 'EIN_M3_ITU_MIB';
                };
            }
	    my $name;
            my $moid;
            my @moid_elems;

	    for my $d_key (keys %$d_ref) {
			$name = $d_key;
			if ($d_ref->{$name} =~ /e\+\d+$/) {
				$d_ref->{$name} = sprintf("%d",$d_ref->{$name});
			}
                        if ( $name =~ /^moid_/ ) {
                                unshift ( @moid_elems, $name . '=' . $d_ref->{$name});
                        }

                        # Add "0" when data is NULL
                        if (! $d_ref->{$name}) {
                                $d_ref->{$name} = 0 ;
                        }
	    }
	    #Create moid counter
            foreach my $elem  (sort @moid_elems) {
                  $moid .= $elem . ',';
            }

            chop($moid);
            $d_ref->{'moid'} = $moid;

            return 0;
        },
    },
    {
        #-----------------------------------------------------------------------
        # XML_3GPP Rule to handle Server Application, Server DS, BW_MedSerMCP Media, 
        # Server DNS and IPMM_Ipwrk_DnsUpdate DNS  
        #-----------------------------------------------------------------------
        RULE_TYPE                        => 'XML_3GPP',
        RULE_DESC                        => '3GPP XML Interface',
        INPUT_FILE_DESCRIPTION           => ['^(A|C)\d{8}\.\d{4}-(\d{8}\.)?(\d{4})_\w+$',
                                             '^(A|C)\d{8}\.\d{4}-(\d{8}\.)?(\d{4})_\w+:\d{1}$'],
        INPUT_DIR_DEPTH                  => 0,
        FILENAME_HEADER_FIELDS           => {
                                              Type       => '^(\w{1})\d{8}.+$',
                                              StartDate  => '^\w{1}(\d{8}).+$',
                                              StartTime  => '^\w{1}\d{8}\.(\d{4}).+$',
                                              Filename   => '^(.*)$',
                                              },
        XML_PIF_HEADER_ELEMENT_NAMES     => ['ffvv-_f.v','sn','st','vn','cbt','nedn','ts','neun'],
        XML_UNIQUE_PIF_BLOCK_HEADER_ELEMENT_NAMES    => ['mts','gp'],
        XML_3GPP_FILENAME_VALIDATION     =>    {
                                                 Type      => '^(A|C)\d{8}.+$',
                                                 StartDate => '^\w{1}(\d{8}).+$',
                                                 StartTime => '^\w{1}\d{8}\.(\d{4}).+$',
                                              },
        XML_HEADER_INFO_FOR_PIF_FILENAME     => ['Type','mts','gp','neun_NE'],
        XML_UNIQUE_PIF_BLOCK_ELEMENT_NAME    => 'mi',
        XML_MEASUREMENT_TYPE_ELEMENT_SEQ     => 'mt',
        XML_MEASUREMENT_VALUE_ELEMENT_NAME   => 'mv',
        XML_MEASUREMENT_RESULTS_ELEMENT_SEQ  => 'r',
        XML_OUTPUT_BLOCK_ELEMENT_NAME        => 'moid',
        XML_OUTPUT_BLOCK_DESCRIPTION         => '^\w+\.(.*)$',
        XML_OBJECT_INSTANCE_ID_ELEMENT_NAME  => 'moid',
        XML_ENABLE_PIF_PER_MOID              => 0,
        XML_SUSPECT_FLAG_ELEMENT_NAME        => 'sf',
        XML_ALTERNATIVE_COUNTER_NULL_VALUE   => '-9999',
        XML_MAX_COUNTER_NAME_SIZE            => 300,
        XML_LINE_COUNT_TO_TOP_TRIM           => 0,
        XML_ENABLE_PIF_COUNTER_IN_FILENAME   => 'True',
        XML_DDM_MANIP_RULES  => ddm_manip_config(),
        # This entry enables extra Perl code in the engine to do various manipulation
        # to header and data records. This is the last process within the engine
        # before the data is being output to the PIF files. Change CSV_DATA to
        # the actual OUTPUT_BLOCK_NAME configured above.
        #
        HEADER_DATA_RECORD_PROCESSING => sub {
            my ($blkname_ref, $h_ref, $d_ref) = @_;

            unless ( exists($h_ref->{GMT_difference}) ) {
                ($h_ref->{GMT_difference}) = $h_ref->{mts} =~ /^\d{14}\.\d{0,4}([+-]?\d{0,4})$/;
            }

            if ($h_ref->{Filename} =~ /^A\d{8}\.\d{4}-\d{4}_\w+$/) {
                $$blkname_ref = 'MGW';
#            } elsif ($h_ref->{Filename} =~ /^C\d{8}\.\d{4}-\d{8}\.\d{4}_\w+$/) {
#                $$blkname_ref = 'MGWCause';
            } elsif ($h_ref->{Filename} =~ /^A\d{8}\.\d{4}-\d{4}_\w+:\d{1}$/) {
		$$blkname_ref = 'MGWCause';
            }
	    my $name;
	    for my $d_key (keys %$d_ref) {
			$name = $d_key;
			if ($d_ref->{$name} =~ /e\+\d+$/) {
				$d_ref->{$name} = sprintf("%d",$d_ref->{$name});
			}

                        # Add "0" when data is NULL
                        if (! $d_ref->{$name}) {
                                $d_ref->{$name} = 0 ;
                        }
#Add moid_mgw and moid_cause

                        if ( $name =~ /^moid/ ) {
                                unless ( exists($d_ref->{moid_mgw}) ) {
                                 ($d_ref->{moid_mgw}) = $d_ref->{$name} =~ /(\w+)\..*/;
                                 ($d_ref->{moid_mgw}) =~ /\"(\w+)/;
                                }
                                unless ( exists($d_ref->{moid_cause}) ) {
                                 ($d_ref->{moid_cause}) = $d_ref->{$name} =~ /\w+\.(.*)/;
                                 ($d_ref->{moid_cause}) =~ s/\"//;
                                 ($d_ref->{moid_cause}) =~ s/ /-/g;
                                }
 			}
			
	    }

            return 0;
        },
    },

);

sub engine_config {
    return \@rules;
}

1;
